@@ -7,7 +7,8 @@ def pow(base, exp):
     """Compute base ^ exp.
 
     :param int base : The base.
-    :param int exp : The exponent."""
+    :param int exp : The exponent.
+    """
     print(base**exp)
 
 
